#[non_exhaustive]pub enum IdentifierValidationKind {
Opaque,
Syntax,
}Expand description
The strength of local validation supplied for a known scheme.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Opaque
Only the generic bounded-text rules apply.
Syntax
The registry checks published syntax without resolving the identifier.