pub struct AgentIdentity { /* private fields */ }Expand description
A person, organization, application instance, or service responsible for an activity.
Implementations
Sourceimpl AgentIdentity
impl AgentIdentity
Sourcepub fn new(
name: Option<String>,
identifier: Option<ExternalIdentifier>,
) -> Result<Self>
pub fn new( name: Option<String>, identifier: Option<ExternalIdentifier>, ) -> Result<Self>
Creates an agent described by a name, an external identifier, or both.
Errors
Returns ErrorKind::InvalidArgument when neither identity is present
or the name is empty, oversized, or contains NUL.
Sourcepub const fn identifier(&self) -> Option<&ExternalIdentifier>
pub const fn identifier(&self) -> Option<&ExternalIdentifier>
Returns the optional external agent identity.