ContentStructure

Struct ContentStructure 

pub struct ContentStructure(/* private fields */);
A validated description of how resources realize one representation.

Implementations

Source

impl ContentStructure

pub const fn single_resource(resource_id: ResourceId) -> Self

Creates a representation backed by one required resource.

pub const fn image_sequence(descriptor: ImageSequenceDescriptor) -> Self

Creates a representation backed by one compact image sequence.

pub fn ordered_parts(members: Vec<ResourceMember>) -> Result<Self>

Creates an ordered span whose members are all required.

Errors

Returns ErrorKind::InvalidArgument when the membership is empty, unbounded, duplicated, or contains an optional member.

pub fn package(members: Vec<ResourceMember>) -> Result<Self>

Creates a package with at least one required member.

Errors

Returns ErrorKind::InvalidArgument when the membership is empty, unbounded, duplicated, or has no required member.

pub const fn kind(&self) -> ContentStructureKind

Returns the structure discriminator.

pub const fn single_resource_id(&self) -> Option<ResourceId>

Returns the resource when this is a single-resource structure.

pub const fn image_sequence_descriptor( &self, ) -> Option<&ImageSequenceDescriptor>

Returns the descriptor when this is an image sequence.

pub fn members(&self) -> Option<&[ResourceMember]>

Returns members for an ordered or package structure.

pub fn resource_ids(&self) -> Vec<ResourceId>

Returns referenced resources in structural order.