pub struct HostObjectBinding { /* private fields */ }Expand description
Portable reference from a host document to one production-scoped object.
Implementations
Sourceimpl HostObjectBinding
impl HostObjectBinding
Sourcepub fn new(production_id: ProductionId, object: ObjectRef) -> Result<Self>
pub fn new(production_id: ProductionId, object: ObjectRef) -> Result<Self>
Creates a binding from its authoritative identity tuple.
Errors
Returns an error when a production object does not match the binding’s containing production identity.
Sourcepub const fn production_id(self) -> ProductionId
pub const fn production_id(self) -> ProductionId
Returns the production that scopes the referenced object identity.