pub struct TransactionLifecycle { /* private fields */ }Expand description
A small state machine shared by storage-backed domain transactions.
Implementations
Sourceimpl TransactionLifecycle
impl TransactionLifecycle
Sourcepub const fn with_id(id: TransactionId) -> Self
pub const fn with_id(id: TransactionId) -> Self
Creates an open transaction with an existing identity.
Sourcepub const fn id(self) -> TransactionId
pub const fn id(self) -> TransactionId
Returns the transaction identity.
Sourcepub const fn state(self) -> TransactionState
pub const fn state(self) -> TransactionState
Returns the current state.
Sourcepub fn ensure_open(self) -> Result<()>
pub fn ensure_open(self) -> Result<()>
Ensures that a mutation may be staged.
Errors
Returns ErrorKind::Conflict if the transaction is already closed.
Sourcepub fn mark_committed(&mut self) -> Result<()>
pub fn mark_committed(&mut self) -> Result<()>
Marks the transaction committed after the backend commit succeeds.
Errors
Returns ErrorKind::Conflict if the transaction is already closed.
Sourcepub fn mark_rolled_back(&mut self) -> Result<()>
pub fn mark_rolled_back(&mut self) -> Result<()>
Marks the transaction rolled back after staged work is discarded.
Errors
Returns ErrorKind::Conflict if the transaction is already closed.