pub struct RationalTime { /* private fields */ }Expand description
An exact integer value measured at a rational rate.
Implementations
Sourceimpl RationalTime
impl RationalTime
Sourcepub const fn new(value: i64, rate: RationalRate) -> Self
pub const fn new(value: i64, rate: RationalRate) -> Self
Creates a rational time value.
Sourcepub const fn rate(self) -> RationalRate
pub const fn rate(self) -> RationalRate
Returns the rate used to interpret the value.
Sourcepub fn checked_cmp(self, other: Self) -> Result<Ordering>
pub fn checked_cmp(self, other: Self) -> Result<Ordering>
Compares two time values exactly without floating-point conversion.
Errors
Returns ErrorKind::InvalidArgument if checked cross multiplication
exceeds the internal comparison range.
Sourcepub fn equivalent(self, other: Self) -> Result<bool>
pub fn equivalent(self, other: Self) -> Result<bool>
Returns whether two values denote the same exact time.
Errors
Returns an error under the same conditions as Self::checked_cmp.
Sourcepub fn rescaled_to(self, rate: RationalRate) -> Result<Self>
pub fn rescaled_to(self, rate: RationalRate) -> Result<Self>
Converts this value to rate when the result is an exact integer.
Errors
Returns ErrorKind::InvalidArgument if the target rate cannot
represent the time exactly or the converted value exceeds i64.